<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bn">
<context>
    <name>Application</name>
    <message>
        <location filename="../reader/Application.cpp" line="39"/>
        <source>Document Viewer</source>
        <translation>পাঠ্যপুস্তক দর্শক</translation>
    </message>
    <message>
        <location filename="../reader/Application.cpp" line="40"/>
        <source>Document Viewer is a tool for reading document files, supporting PDF, DJVU, DOCX etc.</source>
        <translation>পাঠ্যপুস্তক দর্শক একটি সাধনা যা দокумент ফাইল পড়তে সাহায্য করে, PDF, DJVU, DOCX ইত্যাদি সমর্থন করে।</translation>
    </message>
</context>
<context>
    <name>AttrScrollWidget</name>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="46"/>
        <source>Location</source>
        <translation>স্থান</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="47"/>
        <source>Subject</source>
        <translation>শাস্ত্র</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="48"/>
        <source>Author</source>
        <translation>লেখক</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="49"/>
        <source>Keywords</source>
        <translation>শব্দগুলি</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="50"/>
        <source>Producer</source>
        <translation>প্রদর্শনকারী</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="51"/>
        <source>Creator</source>
        <translation>প্রবর্তক</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="52"/>
        <source>Time created</source>
        <translation>তৈরি করা সময়</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="53"/>
        <source>Time modified</source>
        <translation>সময় পরিবর্তন করা</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="54"/>
        <source>Format</source>
        <translation>রূপ</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="55"/>
        <source>Pages</source>
        <translation>পাতা</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="56"/>
        <source>Optimized</source>
        <translation>অভ্যন্তরীণ</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="57"/>
        <source>Security</source>
        <translation>সুরক্ষা</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="59"/>
        <source>Page size</source>
        <translation>পাতা আকার</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="60"/>
        <source>File size</source>
        <translation>ফাইল আকার</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="65"/>
        <source>Basic info</source>
        <translation>ভিত্তি তথ্য</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="85"/>
        <source>Unknown</source>
        <translation>অজানা</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="127"/>
        <source>Yes</source>
        <translation>হ্যাঁ</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="127"/>
        <source>No</source>
        <translation>না</translation>
    </message>
</context>
<context>
    <name>BookMarkWidget</name>
    <message>
        <location filename="../reader/sidebar/BookMarkWidget.cpp" line="64"/>
        <source>Add bookmark</source>
        <translation>বইমার্ক যোগ করুন</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/BookMarkWidget.cpp" line="220"/>
        <source>Are you sure you want to delete all bookmarks?</source>
        <translation>আপনি সত্যিই আপনার সব বইমার্ক থামানো চান?
</translation>
    </message>
</context>
<context>
    <name>BrowserMenu</name>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="39"/>
        <source>Copy</source>
        <translation>কopi</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="43"/>
        <source>Remove annotation</source>
        <translation>মার্কার পরিষেবা বাদ দিন</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="44"/>
        <source>Add annotation</source>
        <translation>মার্কার যোগ করুন</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="47"/>
        <source>Remove bookmark</source>
        <translation>বইমার্ক মুছে ফেলুন</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="49"/>
        <source>Add bookmark</source>
        <translation>বইমার্ক যোগ করুন</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="60"/>
        <source>Highlight</source>
        <translation>আলোচনা</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="69"/>
        <source>Remove highlight</source>
        <translation>আলোচনা মুছে ফেলুন</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="81"/>
        <source>Search</source>
        <translation>অনুসন্ধান</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="92"/>
        <source>Exit fullscreen</source>
        <translation>ফুল স্কিন থেকে বের হো</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="94"/>
        <source>Fullscreen</source>
        <translation>ফুল স্কিন</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="97"/>
        <source>Slide show</source>
        <translation>প্রেzent সাইল</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="100"/>
        <source>First page</source>
        <translation>প্রথম পাতা</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="101"/>
        <source>Previous page</source>
        <translation>পূর্বোক্ত পাতা</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="107"/>
        <source>Next page</source>
        <translation>পরবর্তী পাতা</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="108"/>
        <source>Last page</source>
        <translation>সর্বশেষ পাতা</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="116"/>
        <source>Rotate left</source>
        <translation>বামে ঘূর্ণিত করুন</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="117"/>
        <source>Rotate right</source>
        <translation>ডানে ঘূর্ণিত করুন</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="120"/>
        <source>Print</source>
        <translation>প্রিন্ট করুন</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="121"/>
        <source>Document info</source>
        <translation>প্রতিবেদন তথ্য</translation>
    </message>
</context>
<context>
    <name>Central</name>
    <message>
        <location filename="../reader/uiframe/Central.cpp" line="147"/>
        <source>Documents</source>
        <translation>প্রতিবেদন</translation>
    </message>
</context>
<context>
    <name>CentralDocPage</name>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="166"/>
        <source>The format is not supported</source>
        <translation>ফর্ম্যাট সমর্থিত নয়</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="208"/>
        <source>Open failed</source>
        <translation>বন্ধ হয়ে গেছে</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="210"/>
        <source>Please check if the file is damaged</source>
        <translation>ফাইলটি বাটা আছে কিনা পরীক্ষা করুন</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="212"/>
        <source>Conversion failed, please check if the file is damaged</source>
        <translation>পরিবর্তন সমর্থিত নয়, ফাইলটি বাটা আছে কিনা পরীক্ষা করুন</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="420"/>
        <source>Save failed</source>
        <translation>সংরক্ষণ সমর্থিত নয়</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="426"/>
        <source>Saved successfully</source>
        <translation>সফলভাবে সংরক্ষিত</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="444"/>
        <source>Save as</source>
        <translation>অন্য নামে সংরক্ষণ করুন</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="453"/>
        <source>Invalid file name</source>
        <translation>অকৃত্রিম ফাইল নাম</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="455"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>হ্যাঁ</translation>
    </message>
</context>
<context>
    <name>CentralNavPage</name>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="35"/>
        <source>Drag documents here</source>
        <translation>ডকুমেন্ট গুলি এখানে টানুন</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="41"/>
        <source>Format supported: %1</source>
        <translation>যে ফরমেট সমর্থিত: %1</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="47"/>
        <source>Select File</source>
        <translation>ফাইল নির্বাচন করুন</translation>
    </message>
</context>
<context>
    <name>DocSheet</name>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="332"/>
        <source>The bookmark has been removed</source>
        <translation>আপনার বুকমার্ক অপসারণ করা হয়েছে</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="533"/>
        <source>Please select the text</source>
        <translation>দয়া করে টেক্সট নির্বাচন করুন</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="598"/>
        <source>The annotation has been removed</source>
        <translation>আপনার অ্যানোটেশন অপসারণ করা হয়েছে</translation>
    </message>
</context>
<context>
    <name>EncryptionPage</name>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="50"/>
        <source>Encrypted file, please enter the password</source>
        <translation>কী সম্প্রসারিত ফাইল, দয়া করে কী লিখুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="56"/>
        <source>Password</source>
        <translation>কী</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="61"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>হ্যাঁ</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="105"/>
        <source>Wrong password</source>
        <translation>ভুল কী</translation>
    </message>
</context>
<context>
    <name>FindWidget</name>
    <message>
        <location filename="../reader/widgets/FindWidget.cpp" line="127"/>
        <source>Previous</source>
        <translation>পূর্ববর্তী</translation>
    </message>
    <message>
        <location filename="../reader/widgets/FindWidget.cpp" line="135"/>
        <source>Next</source>
        <translation>পরবর্তী</translation>
    </message>
</context>
<context>
    <name>HandleMenu</name>
    <message>
        <location filename="../reader/widgets/HandleMenu.cpp" line="35"/>
        <source>Select Text</source>
        <translation>টেক্সট নির্বাচন করুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/HandleMenu.cpp" line="43"/>
        <source>Hand Tool</source>
        <translation>হ্যাঁন্ড টুল</translation>
    </message>
</context>
<context>
    <name>NotesWidget</name>
    <message>
        <location filename="../reader/sidebar/NotesWidget.cpp" line="67"/>
        <source>Add annotation</source>
        <translation>নোট যোগ করুন</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/NotesWidget.cpp" line="189"/>
        <source>Are you sure you want to delete all annotations?</source>
        <translation>আপনি সব অ্যানোটেশন মুছে ফেলতে চান কি?</translation>
    </message>
</context>
<context>
    <name>PagingWidget</name>
    <message>
        <location filename="../reader/widgets/PagingWidget.cpp" line="212"/>
        <source>Invalid page number</source>
        <translation>অবৈধ পেজ নম্বর</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../reader/widgets/ProgressDialog.cpp" line="18"/>
        <source>Converting</source>
        <translation>পরিবর্তন করা হচ্ছে</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../reader/app/DBusObject.cpp" line="103"/>
        <source>Document not saved</source>
        <translation>ডকুমেন্ট সংরক্ষণ করা হয়নি</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="35"/>
        <source>Save the changes to "%1"?</source>
        <translation>"%1" ফাইলে পরিবর্তনগুলি সংরক্ষণ করতে চান কি?</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="37"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>বাতিল</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="37"/>
        <source>Discard</source>
        <comment>button</comment>
        <translation>বাতিল করুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="38"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>পরিসংখ্যান</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="49"/>
        <source>Cancel</source>
        <translation>বাতিল</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="50"/>
        <source>Delete</source>
        <translation>পারিবারিক মুছে ফেলুন</translation>
    </message>
</context>
<context>
    <name>ScaleMenu</name>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="35"/>
        <source>Two-Page View</source>
        <translation>দুই পাতার দৃষ্টিভাব</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="36"/>
        <source>1:1 size</source>
        <translation>1:1 আকার</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="37"/>
        <source>Fit Page</source>
        <translation>পাতাটি যোগাযোগ করুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="38"/>
        <source>Fit Height</source>
        <translation>উচ্চতায় যোগাযোগ করুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="39"/>
        <source>Fit Width</source>
        <translation>প্রস্থে যোগাযোগ করুন</translation>
    </message>
</context>
<context>
    <name>SearchResWidget</name>
    <message>
        <location filename="../reader/sidebar/SearchResWidget.cpp" line="60"/>
        <source>No search results</source>
        <translation>নাই সার্চ ফলাফল</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SearchResWidget.cpp" line="111"/>
        <source>%1 items found</source>
        <translation>%1 উপাত্ত পাওয়া গেছে</translation>
    </message>
</context>
<context>
    <name>SecurityDialog</name>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="72"/>
        <source>This document is trying to connect to:</source>
        <translation>এই ডকুমেন্টটি সংযোগ করতে চেষ্টা করছে:</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="73"/>
        <source>If you trust the website, click Allow, otherwise click Block.</source>
        <translation>যদি আপনি ওয়েবসাইটটি সমর্থন করতে চান, তবে Allow বাটনে ক্লিক করুন, অন্যথায় Block বাটনে ক্লিক করুন.</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="76"/>
        <source>Block</source>
        <comment>button</comment>
        <translation>বাঁচান</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="77"/>
        <source>Allow</source>
        <comment>button</comment>
        <translation>সমর্থন করুন</translation>
    </message>
</context>
<context>
    <name>SheetSidebar</name>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="84"/>
        <source>Thumbnails</source>
        <translation>মুছে ফেলুন</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="99"/>
        <source>Catalog</source>
        <translation>কাটালগ</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="112"/>
        <source>Bookmarks</source>
        <translation>বুকমার্কস</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="127"/>
        <source>Annotations</source>
        <translation>নকশা</translation>
    </message>
</context>
<context>
    <name>ShortCutShow</name>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="60"/>
        <source>Settings</source>
        <translation>সেটিংস</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="124"/>
        <source>Exit</source>
        <translation>বের হওয়া</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="100"/>
        <source>Help</source>
        <translation>সাহায্য</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="120"/>
        <source>Page up</source>
        <translation>পাতার উপরে</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="121"/>
        <source>Page down</source>
        <translation>পাতার নিচে</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="105"/>
        <source>Open</source>
        <translation>নিখুঁত করুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="118"/>
        <source>Zoom in</source>
        <translation>বৃদ্ধি করুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="119"/>
        <source>Zoom out</source>
        <translation>কমান</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="106"/>
        <source>Save as</source>
        <translation>পরিবর্তে সেভ করুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="107"/>
        <source>Print</source>
        <translation>প্রিন্ট</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="108"/>
        <source>Save</source>
        <translation>সংরক্ষণ</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="112"/>
        <source>Thumbnails</source>
        <translation>থামবন্স</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="113"/>
        <source>1:1 size</source>
        <translation>1:1 আকার</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="114"/>
        <source>Fit height</source>
        <translation>উচ্চতায় সুষম রাখুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="115"/>
        <source>Fit width</source>
        <translation>প্রস্থে সুষম রাখুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="116"/>
        <source>Rotate left</source>
        <translation>বামে ঘুরান</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="117"/>
        <source>Rotate right</source>
        <translation>ডানে ঘুরান</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="122"/>
        <source>Move to the beginning</source>
        <translation>শুরুর দিকে সরান</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="123"/>
        <source>Move to the end</source>
        <translation>শেষের দিকে সরান</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="128"/>
        <source>Select text</source>
        <translation>টেক্সট নির্বাছন করুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="129"/>
        <source>Hand tool</source>
        <translation>হাতের টুল</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="130"/>
        <source>Add bookmark</source>
        <translation>বুকমার্ক যোগ করুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="143"/>
        <source>Delete</source>
        <translation>পাতাটি মুছে ফেলুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="133"/>
        <source>Magnifier</source>
        <translation>বিশদবুক্স</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="135"/>
        <source>Slide show</source>
        <translation>ছবি প্রদর্শন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="136"/>
        <source>Fullscreen</source>
        <translation>ফুল স্কিউন্স</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="140"/>
        <source>Copy</source>
        <translation>কপি করুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="141"/>
        <source>Cut</source>
        <translation>কাট করুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="142"/>
        <source>Paste</source>
        <translation>পেস্ট করুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="144"/>
        <source>Undo</source>
        <translation>রিবায়ে করুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="145"/>
        <source>Select all</source>
        <translation>সব নির্বাছন করুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="101"/>
        <source>Display shortcuts</source>
        <translation>শটকুট দেখান</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="131"/>
        <source>Add annotation</source>
        <translation>নোট যোগ করুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="132"/>
        <source>Highlight</source>
        <translation>অনুক্ষেপ করুন</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="134"/>
        <source>Search</source>
        <translation>অনুসন্ধান</translation>
    </message>
</context>
<context>
    <name>SideBarImageListView</name>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="194"/>
        <source>Copy</source>
        <translation>কপি</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="199"/>
        <source>Remove annotation</source>
        <translation>অন্মাল পাড়ো</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="204"/>
        <source>Remove all</source>
        <translation>সব পাড়ো</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="218"/>
        <source>Remove bookmark</source>
        <translation>বইমার্ক পাড়ো</translation>
    </message>
</context>
<context>
    <name>SideBarImageViewModel</name>
    <message>
        <location filename="../reader/sidebar/SideBarImageViewModel.cpp" line="135"/>
        <source>Page %1</source>
        <translation>%1 পাতা</translation>
    </message>
</context>
<context>
    <name>SlidePlayWidget</name>
    <message>
        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="127"/>
        <source>It is the first page</source>
        <translation>এটি প্রথম পাতা</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="132"/>
        <source>It is the last page</source>
        <translation>এটি শেষ পাতা</translation>
    </message>
</context>
<context>
    <name>TitleMenu</name>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="29"/>
        <source>New window</source>
        <translation>নতুন বার্টন</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="29"/>
        <source>New tab</source>
        <translation>নতুন টাব</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="39"/>
        <source>Save</source>
        <translation>পরিসংখ্যান</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="39"/>
        <source>Save as</source>
        <translation>কেমন করে পরিসংখ্যান</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="44"/>
        <source>Display in file manager</source>
        <translation>ফাইল ম্যানেজারে প্রদর্শন</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="44"/>
        <source>Magnifer</source>
        <translation>মাগনিফায়ার</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="50"/>
        <source>Tools</source>
        <translation>ব্যবস্থাপনা</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
        <source>Search</source>
        <translation>অনুসন্ধান</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
        <source>Print</source>
        <translation>প্রিন্ট</translation>
    </message>
</context>
<context>
    <name>TitleWidget</name>
    <message>
        <location filename="../reader/uiframe/TitleWidget.cpp" line="37"/>
        <source>Thumbnails</source>
        <translation>থিম্বনাইল</translation>
    </message>
</context>
<context>
    <name>TransparentTextEdit</name>
    <message>
        <location filename="../reader/widgets/TransparentTextEdit.cpp" line="82"/>
        <source>Input limit reached</source>
        <translation>ইনপুটের সীমা পৌঁছাল</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../reader/main.cpp" line="40"/>
        <source>Document File Path.</source>
        <translation>পাঠ্যপত্র ফাইল পথ।</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="41"/>
        <source>FilePath</source>
        <translation>ফাইল পথ</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="44"/>
        <source>ThumbnailPath Path.</source>
        <translation>থিম্বনাইল পথ।</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="49"/>
        <source>Generate thumbnail.</source>
        <translation>থিম্বনাইল তৈরি করুন।</translation>
    </message>
</context>
</TS>
